@@ -7,11 +7,11 @@ from pydatasource.core.documentation import document_treat_query
 from pydatasource.core.snippet import treat_all_snippet
 from dacktool import log_info, log_error
 
-from pydatasource.core.staging_comparison import compute_staging_comparison
+from pydatasource.core.environment_comparison import compute_comparison
 
 
 class DataSource:
-    def __init__(self, dbstream: DBStream, path_to_datasource_folder, schema_prefix=None):
+    def __init__(self, dbstream: DBStream, path_to_datasource_folder, schema_prefix=None, config_name='config'):
         """
 
         :param dbstream:
@@ -20,6 +20,7 @@ class DataSource:
         self.dbstream = dbstream
         self.path_to_datasource_folder = path_to_datasource_folder
         self.schema_prefix = schema_prefix
+        self.config_name = config_name
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
@@ -55,7 +56,7 @@ class DataSource:
 
     def _get_query_list(self, layer_name, query_name=None):
         folder_path = self._build_folder_path(layer_name)
-        config = yaml.load(open(folder_path + "config.yaml"), Loader=yaml.FullLoader)
+        config = yaml.load(open(folder_path + ("%s.yaml" % self.config_name)), Loader=yaml.FullLoader)
         queries = config.get("queries")
         schema_name = config.get("schema_name") if config.get("schema_name") else ("datasource_" + layer_name)
         schema_name = self.schema_prefix + '_' + schema_name if self.schema_prefix else schema_name
@@ -65,7 +66,7 @@ class DataSource:
         query_list = [query_name] if query_name else list(queries.keys())
         return query_list, queries, schema_name, folder_path
 
-    def _filled_query(self, queries, query, folder_path, schema_name, layer_name, staging):
+    def _filled_query(self, queries, query, folder_path, schema_name, layer_name, environment='production'):
         query_config = queries[query]
         if query_config.get("template"):
             query_template_file_name = query_config.get("template")
@@ -83,8 +84,8 @@ class DataSource:
             for params in query_params.keys():
                 value = query_params[params]
                 if isinstance(value, dict):
-                    if staging:
-                        value = value["staging"]
+                    if environment != 'production':
+                        value = value[environment]
                     else:
                         value = value["production"]
                 if value == "now":
@@ -100,26 +101,28 @@ class DataSource:
         filled_query = query_template.substitute(dict_params)
         return filled_query
 
-    def compute(self, layer_name, query_name=None, staging=False):
+    def compute(self, layer_name, query_name=None, environment="production"):
         query_list, queries, schema_name, folder_path = self._get_query_list(layer_name, query_name=query_name)
 
         for query in query_list:
-            log_info("Layer: %s | Query started: %s | Staging mode: %s" % (layer_name, query, staging))
+            log_info("Layer: %s | Query started: %s | Environment: %s" % (layer_name, query, environment))
             filled_query = self._filled_query(
                 queries=queries,
                 query=query,
                 folder_path=folder_path,
-                schema_name=schema_name if not staging else (schema_name + "_staging"),
+                schema_name=schema_name if environment == 'production' else (schema_name + "_" + environment),
                 layer_name=layer_name,
-                staging=staging
+                environment=environment
             )
             table_name = query
-
+            if environment != "production":
+                log_info(filled_query)
             try:
                 self.dbstream.execute_query(filled_query)
             except Exception as e:
                 if "schema" in str(e):
-                    self.dbstream.create_schema(schema_name if not staging else (schema_name + "_staging"))
+                    self.dbstream.create_schema(
+                        schema_name if environment == 'production' else (schema_name + "_" + environment))
                     self.dbstream.execute_query(filled_query)
                 else:
                     sec_before_retry = 15
@@ -129,22 +132,22 @@ class DataSource:
                     self.dbstream.execute_query(filled_query)
 
             # LOG NORMAL
-            if not staging:
+            if environment == 'production':
                 log_info(table_name + " created")
 
-            if not staging and queries[query].get("beautiful_view"):
+            if environment == 'production' and queries[query].get("beautiful_view"):
                 self._create_beautiful_view(table_name, schema_name)
-            if not staging and queries[query].get("gds"):
+            if environment == 'production' and queries[query].get("gds"):
                 self._create_gds_view(table_name, schema_name)
 
-        if staging:
-            compute_staging_comparison(self.dbstream, schema_name, query_list)
+        if environment != 'production':
+            compute_comparison(self.dbstream, schema_name, query_list, environment)
 
         return 0
 
-    def function_compute(self, layer_name, staging=False):
+    def function_compute(self, layer_name, environment='production'):
         def f():
-            self.compute(layer_name, staging)
+            self.compute(layer_name, environment)
 
         return f
 
